<?php

namespace Admin\Service\Common\PhoneSms;


use Admin\Data\Common;
use Laminas\Json\Json;

class Smsbao
{
    
    private $sendUrl = 'http://api.smsbao.com/sms?';
    private $smsConfig;


    /**
     * 设置短信
     * @param $smsConfig
     * @throws ClientException
     */
    public function setSmsConfig($smsConfig)
    {
        $this->smsConfig = $smsConfig;
    }

    /**
     * 发送短信
     * @param array $data
     * @return bool
     */
    public function sendPhoneSms(array $data)
    {
        $smsContent = $this->getSmsContent($data['typeCode'], $data['contentArray'], $data['templateCode']);
        if (empty($smsContent)) return;
        if (empty($data['phone'])) return;
        foreach ($data['phone'] as $phoneValue) {
            $this->sendSmsbao($phoneValue['number'], $smsContent);
        }
    }

    /**
     * 发送订单短信
     * @param array $data
     * @return bool
     */
    public function sendOrderPhoneSms(array $data)
    {
        $smsContent = $this->getSmsContent($data['typeCode'], $data['contentArray'], $data['templateCode']);
        if (empty($smsContent)) return;
        if (empty($data['phone'])) return;

        foreach ($data['phone'] as $phoneValue) {
            $this->sendSmsbao($phoneValue['number'], $smsContent);
        }
    }

      /**
     * 发送短信方法
     * @param $phone
     * @param $content
     * @return array|bool|string|null
     */
    private function sendSmsbao($phone, $content)
    {
        $statusStr = array(
                "0" => "短信发送成功",
                "-1" => "参数不全",
                "-2" => "服务器空间不支持,请确认支持curl或者fsocket，联系您的空间商解决或者更换空间！",
                "30" => "密码错误",
                "40" => "账号不存在",
                "41" => "余额不足",
                "42" => "帐户已过期",
                "43" => "IP地址限制",
                "50" => "内容含有敏感词",
                "51" => "手机号码不正确"
            );

        try {
            $user = $this->smsConfig['sms_id'];
            $pass = $this->smsConfig['sms_secret'];
            $content = '【'.$this->smsConfig['sms_sign_name'].'】'.$content;
            $sendurl = $this->sendUrl."u=".$user."&p=".$pass."&m=".$phone."&c=".urlencode($content);
            $result = $this->curl_get($sendurl);
            return $statusStr[$result];
        } catch (\Exception $e) {
            return null;
        }

        return null;
    }

     private function curl_get($sendurl){
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $sendurl);
        curl_setopt($ch, CURLOPT_TIMEOUT, 1);
        curl_setopt($ch, CURLOPT_USERAGENT, $_SERVER["HTTP_USER_AGENT"]);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $result = curl_exec($ch);
        curl_close($ch);
        return $result;
    }

  

      /**
     * 获取短信内容
     * @param $type
     * @param $data
     * @param $templateCode
     * @return string
     */
    private function getSmsContent($type, $data, $templateCode)
    {
        $TemplateCodeContent = '';
        switch ($type) {
            case 'captcha':
                $TemplateCodeContent = str_replace('{code}', $data['phoneCaptcha'], $templateCode);
                break;
            case 'addOrder':
                $TemplateCodeContent = str_replace(['{buyName}', '{orderSn}', '{orderTotal}'], [$data['buyName'], $data['orderSn'], $data['orderTotal']], $templateCode);
                break;
            case 'cancelOrder':
                $TemplateCodeContent = str_replace(['{buyName}', '{orderSn}', '{orderTotal}'], [$data['buyName'], $data['orderSn'], $data['orderTotal']], $templateCode);
                break;
            case 'paymentOrder':
                $TemplateCodeContent = str_replace(['{buyName}', '{orderSn}', '{orderTotal}'], [$data['buyName'], $data['orderSn'], $data['orderTotal']], $templateCode);
                break;
            case 'shipOrder':
                $TemplateCodeContent = str_replace(['{buyName}', '{orderSn}', '{orderTotal}', '{deliveryName}', '{expressNumber}'], [$data['buyName'], $data['orderSn'], $data['orderTotal'], $data['deliveryName'], $data['expressNumber']], $templateCode);
                break;
            case 'receiptOrder':
                $TemplateCodeContent = str_replace(['{buyName}', '{orderSn}', '{orderTotal}', '{deliveryName}', '{expressNumber}'], [$data['buyName'], $data['orderSn'], $data['orderTotal'], $data['deliveryName'], $data['expressNumber']], $templateCode);
                break;
        }

        return $TemplateCodeContent;
    }
}